/*++

Copyright (c) 2010 Test Equipment Plus.

Module Name:

    SHAPI.h

Abstract:

    Native Signal Hound / USB device driver for Signal Hound Firmware version 1.2 or later
    Signal Hound API library definitions


Revision History:

    3/09/2010   JBC     Created.
    3/10/2010   JBC     Added function calls from SH_API.dll
    3/25/2010   JBC     Added additional function calls from SH_API.dll
    10/13/2010  JBC     Added Measurement Receiver structure and function.
	
	
--*/

#pragma once

struct MEAS_RCVR_STRUCT
{
	// *** INPUTS ***
	double	RFFrequency;	//RF carrier frequency (center)
	double	AudioLPFreq;	//Audio LowPass Cutoff 
	double	AudioBPFreq;	//Audio BandPass Center
	int		UseLPF;			//Set to non-zero to use audio low-pass filter 
	int		UseBPF;			//Set to non-zero to use audio low-pass filter
	
	// *** OUTPUTS ***
	double	RFCounter;		//RF frequency count out
	double	AMAudioFreq;	//AF frequency count out after AM demod
	double	FMAudioFreq;	//AF frequency count out after FM demod
	double	RFAmplitude;	//dB Full Scale.  

	double	FMPeakPlus;
	double	FMPeakMinus;
	double	FMRMS;

	double	AMPeakPlus;
	double	AMPeakMinus;
	double	AMRMS;

};

//////////////////////////////////////////////////////////
// double SHAPI_GetRBW(int FFTSize, int decimation)
// Arguments: FFT size, decimation setting
// Returns calculated estimated RBW.
//////////////////////////////////////////////////////////
__declspec( dllimport ) double SHAPI_GetRBW(int FFTSize, int decimation);


//////////////////////////////////////////////////////////
// int SHAPI_Initialize()
// Initializes USB and loads cal table.
// TAKES 15 seconds to complete!!!
// Arguments: none 
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_Initialize();


//////////////////////////////////////////////////////////
// int SHAPI_SetAttenuator(double attenVal)
// Sets attenuator to nearest value of 0,5,10, or 15 dB
// Arguments: double attenVal.
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_SetAttenuator(double attenVal);


//////////////////////////////////////////////////////////
// int SHAPI_SelectExt10MHz()
// Selects external reference
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_SelectExt10MHz();


//////////////////////////////////////////////////////////
// SHAPI_Configure(double attenVal, ... )
// Sets attenuator to nearest value of 0,5,10, or 15 dB
// Selects mixer as either low band (value=0) or high band (value=1)
// Selects sensitivity as 0=low, 1=mid, or 2=high sensitivity
// Selects decimation as [1..16]
// Selects IF path as either 2.92 (value=1) or 10.7 MHz (value=0)
// Selects clock as 23.33 MHz (value=0) or 22.5 MHz (value=1) 
// Arguments: double attenVal=10, int mixerBand=1, int sensitivity=0,  
//												   int decimation=1, int useIF2_9=0, int ADCclock=0
// Returns 0 for success, otherwise returns error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_Configure(double attenVal=10.0, int mixerBand=1, int sensitivity=0,  
												   int decimation=1, int useIF2_9=0, int ADCclock=0);

// Same, except processes only settings that have changed
__declspec( dllimport ) int SHAPI_ConfigureFast(double attenVal=10.0, int mixerBand=1, int sensitivity=0,  
												   int decimation=1, int useIF2_9=0, int ADCclock=0);


//////////////////////////////////////////////////////////
// SHAPI_GetSlowSweep
// See Signal Hound API documentation
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_GetSlowSweep(double * dBArray, double startFreq, double stopFreq,  
													  int &returnCount, int FFTSize=1024, 
													  int avgCount=16, int imageHandling=0);


													  
//////////////////////////////////////////////////////////
// SHAPI_GetFastSweep
// See Signal Hound API documentation
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_GetFastSweep(double * dBArray, double startFreq, double stopFreq,  
													  int &returnCount, int FFTSize=16, int imageHandling=0);

//////////////////////////////////////////////////////////
// SHAPI_GetSlowSweepCount
// Returns number of samples in proposed sweep
//////////////////////////////////////////////////////////
__declspec( dllexport ) int SHAPI_GetSlowSweepCount(double startFreq, double stopFreq, int FFTSize);

//////////////////////////////////////////////////////////
// SHAPI_GetFastSweepCount
// Returns number of samples in proposed sweep
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_GetFastSweepCount(double startFreq, double stopFreq,int FFTSize);

//////////////////////////////////////////////////////////
// SHAPI_CyclePort
// Returns 0 for success, or error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_CyclePort();

//////////////////////////////////////////////////////////
// SHAPI_GetIQDataPacket
// Returns 0 for success, or error code.
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_GetIQDataPacket(int * pIData, int * pQData, double &centerFreq, int size);


//////////////////////////////////////////////////////////
// SHAPI_Authenticate()
// Returns 1 if authentication passes, 0 if authentication fails
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_Authenticate(int vendorcode=0);

//////////////////////////////////////////////////////////
// int SHAPI_CopyCalTable(unsigned char * p4KTable)
// Copies cal data from DLL memory into user array.
// User MUST allocate 4096 bytes
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_CopyCalTable(unsigned char * p4KTable);

//////////////////////////////////////////////////////////
// int SHAPI_InitializeEx(unsigned char * p4KTable)
// Initializes USB with provided cal table.
// TAKES <1 second to complete
// User MUST provide 4096 bytes from SHAPI_CopyCalTable
// Returns 0 for success, otherwise returns error code.
//
//
// To use: 
//  1) Call SHAPI_Initialize
//  2) Call SHAPI_CopyCalTable
//  3) Store the 4K cal data into a convenient location
//
// To quickly load the Signal Hound thereafter: 
//  4) Call SHAPI_InitializeEx with the 4K from steps 2-3 instead of initialize
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_InitializeEx(unsigned char * p4KTable);

//////////////////////////////////////////////////////////
// SHAPI_SetupLO(double centerFreq, int mixMode=1)
// Mix mode = 0 for low-side injection
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_SetupLO(double &centerFreq, int mixMode=1);

//////////////////////////////////////////////////////////
// SHAPI_StartStreamingData();
// From here, repeatedly use GetStreamingPacket
// Then call StopStreamingData before doing anything else!!!
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_StartStreamingData();

//////////////////////////////////////////////////////////
// SHAPI_StopStreamingData();
// After using GetStreamingPacket
//  call StopStreamingData before doing anything else!!!
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_StopStreamingData();

//////////////////////////////////////////////////////////
// SHAPI_GetStreamingPacket(int *bufI, int *bufQ);
// Gets 4K tokens
// Then call StopStreamingData before doing anything else!!!
//////////////////////////////////////////////////////////
__declspec( dllimport ) int SHAPI_GetStreamingPacket(int *bufI, int *bufQ);

//////////////////////////////////////////////////////////
// int SHAPI_GetLastChannelPower()
// Returns calculated channel power from last SlowSweep
//////////////////////////////////////////////////////////
__declspec( dllimport ) double SHAPI_GetLastChannelPower();

//////////////////////////////////////////////////////////
// int SHAPI_GetLastChannelFreq()
// Returns calculated channel frequency
//////////////////////////////////////////////////////////
__declspec( dllimport ) double SHAPI_GetLastChannelFreq();

//////////////////////////////////////////////////////////
// Returns demodulated audio peak frequencies
//////////////////////////////////////////////////////////
__declspec( dllimport ) double SHAPI_GetFMFFTPK();
__declspec( dllimport ) double SHAPI_GetAMFFTPK();
__declspec( dllimport ) void SHAPI_ActivateAudioFFT();
__declspec( dllimport ) void SHAPI_DeactivateAudioFFT();

__declspec( dllimport ) double SHAPI_GetChannelPower(double cf, int *iBigI, int *iBigQ, int count);
__declspec( dllimport ) int SHAPI_GetIntFFT(int FFTSize, int *iBigI, int *iBigQ, double * dFFTOut);
__declspec( dllimport ) double SHAPI_GetPhaseStep();
__declspec( dllimport ) void SHAPI_CyclePowerOnExit();
__declspec( dllimport ) unsigned int SHAPI_GetSerNum();
__declspec( dllimport ) double SHAPI_GetAudioFFTSample(int idx);
__declspec( dllimport ) float SHAPI_GetTemperature();
__declspec( dllimport ) void SHAPI_SetPreamp(int val);
__declspec( dllimport ) int  SHAPI_RunMeasurementReceiver(void * LPStruct);

__declspec( dllimport ) int SHAPI_IsPreampAvailable();
__declspec( dllimport ) unsigned int SHAPI_GetSerNum();
__declspec( dllimport ) int SHAPI_InitializeNext();
__declspec( dllimport ) int SHAPI_SelectDevice(int deviceToSelect);
__declspec( dllimport ) int SHAPI_SetupLO(double &centerFreq, int mixMode=1, int deviceNum=-1);
__declspec( dllimport ) int SHAPI_StartStreamingData(int deviceNum=-1);
__declspec( dllimport ) int SHAPI_StopStreamingData(int deviceNum=-1);
__declspec( dllimport ) int SHAPI_GetStreamingPacket(int *bufI, int *bufQ, int deviceNum=-1);




